@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use vars qw/$VERSION/;
 
-$Test::Stream::VERSION = '1.302018';
+$Test::Stream::VERSION = '1.302020';
 $VERSION = eval $VERSION;
 
 use Carp qw/croak/;
@@ -209,18 +209,6 @@ __END__
 
 Test::Stream - Experimental successor to Test::More and Test::Builder.
 
-=head1 EXPERIMENTAL CODE WARNING
-
-B<This is an experimental release!> Test-Stream, and all its components are
-still in an experimental phase. This dist has been released to cpan in order to
-allow testers and early adopters the chance to write experimental new tools
-with it, or to add experimental support for it into old tools.
-
-B<PLEASE DO NOT COMPLETELY CONVERT OLD TOOLS YET>. This experimental release is
-very likely to see a lot of code churn. API's may break at any time.
-Test-Stream should NOT be depended on by any toolchain level tools until the
-experimental phase is over.
-
 =head1 ***READ THIS FIRST***
 
 B<This is not a drop-in replacement for Test::More>.
@@ -233,9 +221,32 @@ trivial of test files.
 See L<Test::Stream::Manual::FromTestBuilder> if you are coming from
 L<Test::More> or L<Test::Simple> and want a quick translation.
 
+=head1 ***COMBINING WITH OLD TOOLS***
+
+At the moment you cannot use L<Test::Stream> and L<Test::Builder> based tools
+in the same test scripts unless you install the TRIAL L<Test::More> version.
+Once the L<Test::More> trials go stable you will be able to combine tools from
+both frameworks.
+
 =head1 MANUAL
 
-TODO: Manual
+The manual is still being written, but a couple pages are already available.
+
+=over 4
+
+=item Migrating from Test::More
+
+L<Test::Stream::Manual::FromTestBuilder>
+
+=item How to write tools for Test::Stream
+
+L<Test::Stream::Manual::Tooling>
+
+=item Overview of Test-Stream components
+
+L<Test::Stream::Manual::Components>
+
+=back
 
 =head1 DESCRIPTION
 
@@ -529,6 +540,13 @@ need to set this yourself.
 This is typically set by L<TAP::Harness> and other harnesses. You should not
 need to set this yourself.
 
+=item NO_TRACE_MASK=1
+
+This variable is specified by L<Trace::Mask>. Test::Stream uses the
+L<Trace::Mask> specification to mask some stack frames from traces generated by
+L<Trace::Mask> compliant tools. Setting this variable will force a full stack
+trace whenever a trace is produced.
+
 =back
 
 =head1 SOURCE
