@@ -146,11 +146,9 @@ sub plan {
     $ctx->release;
 }
 
-update_mask('*', '*', __PACKAGE__ . '::done_testing', {restart => 1});
+update_mask('*', '*', __PACKAGE__ . '::done_testing', {lock => 1});
 sub done_testing {
     my $ctx = context();
-    my $state = $ctx->hub->state;
-
     $ctx->hub->finalize($ctx->debug, 1);
     $ctx->release;
 }
@@ -298,21 +296,9 @@ __END__
 
 =head1 NAME
 
-Test::Stream::Plugin::Core - Test::Stream implementation of the core Test::More
+Test::Stream::Plugin::Core - Test::Stream implementation of the core testing
 tools.
 
-=head1 EXPERIMENTAL CODE WARNING
-
-B<This is an experimental release!> Test-Stream, and all its components are
-still in an experimental phase. This dist has been released to cpan in order to
-allow testers and early adopters the chance to write experimental new tools
-with it, or to add experimental support for it into old tools.
-
-B<PLEASE DO NOT COMPLETELY CONVERT OLD TOOLS YET>. This experimental release is
-very likely to see a lot of code churn. API's may break at any time.
-Test-Stream should NOT be depended on by any toolchain level tools until the
-experimental phase is over.
-
 =head1 DESCRIPTION
 
 B<This is not a drop-in replacement for Test::More>.
